============================================================
 :mod:`xotl.tools.testing.unit` -- Utilities for unit tests
============================================================

.. module:: xotl.tools.testing.unit

.. testsetup::

   from xotl.tools.testing.unit import *

.. autofunction:: run_module_doctest

.. autoclass:: ExtendedBaseTestCase
